Index: lemon/maps.h
===================================================================
--- lemon/maps.h	(revision 769)
+++ lemon/maps.h	(revision 771)
@@ -1908,5 +1908,5 @@
   /// The graph items can be accessed by their values either using
   /// \c InverseMap or \c operator()(), and the values of the map can be
   /// accessed with an STL compatible forward iterator (\c ValueIterator).
   /// 
   /// This map is intended to be used when all associated values are
@@ -1962,20 +1962,20 @@
     /// They are considered with multiplicity, so each value is
     /// traversed for each item it is assigned to.
-    class ValueIterator
+    class ValueIt
       : public std::iterator<std::forward_iterator_tag, Value> {
       friend class CrossRefMap;
     private:
-      ValueIterator(typename Container::const_iterator _it)
+      ValueIt(typename Container::const_iterator _it)
         : it(_it) {}
     public:
 
       /// Constructor
-      ValueIterator() {}
+      ValueIt() {}
 
       /// \e
-      ValueIterator& operator++() { ++it; return *this; }
+      ValueIt& operator++() { ++it; return *this; }
       /// \e
-      ValueIterator operator++(int) {
-        ValueIterator tmp(*this);
+      ValueIt operator++(int) {
+        ValueIt tmp(*this);
         operator++();
         return tmp;
@@ -1988,11 +1988,14 @@
 
       /// \e
-      bool operator==(ValueIterator jt) const { return it == jt.it; }
+      bool operator==(ValueIt jt) const { return it == jt.it; }
       /// \e
-      bool operator!=(ValueIterator jt) const { return it != jt.it; }
+      bool operator!=(ValueIt jt) const { return it != jt.it; }
 
     private:
       typename Container::const_iterator it;
     };
+    
+    /// Alias for \c ValueIt
+    typedef ValueIt ValueIterator;
 
     /// \brief Returns an iterator to the first value.
@@ -2002,6 +2005,6 @@
     /// map can be accessed in the <tt>[beginValue, endValue)</tt>
     /// range.
-    ValueIterator beginValue() const {
-      return ValueIterator(_inv_map.begin());
+    ValueIt beginValue() const {
+      return ValueIt(_inv_map.begin());
     }
 
@@ -2012,6 +2015,6 @@
     /// map can be accessed in the <tt>[beginValue, endValue)</tt>
     /// range.
-    ValueIterator endValue() const {
-      return ValueIterator(_inv_map.end());
+    ValueIt endValue() const {
+      return ValueIt(_inv_map.end());
     }
 
@@ -3024,5 +3027,5 @@
   /// For each value it is possible to iterate on the keys mapped to
   /// the value (\c ItemIt), and the values of the map can be accessed
   /// with an STL compatible forward iterator (\c ValueIterator).
   /// The map stores a linked list for each value, which contains
   /// the items mapped to the value, and the used values are stored
@@ -3112,20 +3115,20 @@
     /// iterator on the values of the map. The values can
     /// be accessed in the <tt>[beginValue, endValue)</tt> range.
-    class ValueIterator
+    class ValueIt
       : public std::iterator<std::forward_iterator_tag, Value> {
       friend class IterableValueMap;
     private:
-      ValueIterator(typename std::map<Value, Key>::const_iterator _it)
+      ValueIt(typename std::map<Value, Key>::const_iterator _it)
         : it(_it) {}
     public:
 
       /// Constructor
-      ValueIterator() {}
+      ValueIt() {}
 
       /// \e
-      ValueIterator& operator++() { ++it; return *this; }
+      ValueIt& operator++() { ++it; return *this; }
       /// \e
-      ValueIterator operator++(int) {
-        ValueIterator tmp(*this);
+      ValueIt operator++(int) {
+        ValueIt tmp(*this);
         operator++();
         return tmp;
@@ -3138,7 +3141,7 @@
 
       /// \e
-      bool operator==(ValueIterator jt) const { return it == jt.it; }
+      bool operator==(ValueIt jt) const { return it == jt.it; }
       /// \e
-      bool operator!=(ValueIterator jt) const { return it != jt.it; }
+      bool operator!=(ValueIt jt) const { return it != jt.it; }
 
     private:
@@ -3152,6 +3155,6 @@
     /// map can be accessed in the <tt>[beginValue, endValue)</tt>
     /// range.
-    ValueIterator beginValue() const {
-      return ValueIterator(_first.begin());
+    ValueIt beginValue() const {
+      return ValueIt(_first.begin());
     }
 
@@ -3162,6 +3165,6 @@
     /// map can be accessed in the <tt>[beginValue, endValue)</tt>
     /// range.
-    ValueIterator endValue() const {
-      return ValueIterator(_first.end());
+    ValueIt endValue() const {
+      return ValueIt(_first.end());
     }
 
@@ -3281,7 +3284,7 @@
   public:
 
-    ///\e
+    /// The key type (the \c Arc type of the digraph).
     typedef typename GR::Arc Key;
-    ///\e
+    /// The value type (the \c Node type of the digraph).
     typedef typename GR::Node Value;
 
@@ -3322,7 +3325,7 @@
   public:
 
-    ///\e
+    /// The key type (the \c Arc type of the digraph).
     typedef typename GR::Arc Key;
-    ///\e
+    /// The value type (the \c Node type of the digraph).
     typedef typename GR::Node Value;
 
@@ -3364,6 +3367,8 @@
   public:
 
+    /// The key type (the \c Edge type of the digraph).
+    typedef typename GR::Edge Key;
+    /// The value type (the \c Arc type of the digraph).
     typedef typename GR::Arc Value;
-    typedef typename GR::Edge Key;
 
     /// \brief Constructor
@@ -3404,6 +3409,8 @@
   public:
 
+    /// The key type (the \c Edge type of the digraph).
+    typedef typename GR::Edge Key;
+    /// The value type (the \c Arc type of the digraph).
     typedef typename GR::Arc Value;
-    typedef typename GR::Edge Key;
 
     /// \brief Constructor
@@ -1908,5 +1908,5 @@
   /// The graph items can be accessed by their values either using
   /// \c InverseMap or \c operator()(), and the values of the map can be
-  /// accessed with an STL compatible forward iterator (\c ValueIterator).
+  /// accessed with an STL compatible forward iterator (\c ValueIt).
   /// 
   /// This map is intended to be used when all associated values are
@@ -3024,5 +3027,5 @@
   /// For each value it is possible to iterate on the keys mapped to
   /// the value (\c ItemIt), and the values of the map can be accessed
-  /// with an STL compatible forward iterator (\c ValueIterator).
+  /// with an STL compatible forward iterator (\c ValueIt).
   /// The map stores a linked list for each value, which contains
   /// the items mapped to the value, and the used values are stored
